@@ -607,7 +607,7 @@ QList< QAction * > BookmarkManager::actionsForUrl(const QUrl &url ) const
         }
         break;
     }
-    qSort( ret.begin(), ret.end(), okularBookmarkActionLessThan );
+    std::sort(ret.begin(), ret.end(), okularBookmarkActionLessThan);
     return ret;
 }
 
@@ -705,7 +705,7 @@ bool BookmarkManager::isBookmarked( const DocumentViewport &viewport ) const
 KBookmark BookmarkManager::nextBookmark( const DocumentViewport &viewport) const
 {
     KBookmark::List bmarks = bookmarks();
-    qSort( bmarks.begin(), bmarks.end(), bookmarkLessThan);
+    std::sort(bmarks.begin(), bmarks.end(), bookmarkLessThan);
 
     KBookmark bookmark;
     foreach ( const KBookmark &bm, bmarks )
@@ -724,7 +724,7 @@ KBookmark BookmarkManager::nextBookmark( const DocumentViewport &viewport) const
 KBookmark BookmarkManager::previousBookmark( const DocumentViewport &viewport ) const
 {
     KBookmark::List bmarks = bookmarks();
-    qSort( bmarks.begin(), bmarks.end(), bookmarkLessThan );
+    std::sort(bmarks.begin(), bmarks.end(), bookmarkLessThan);
 
     KBookmark bookmark;
     for ( KBookmark::List::const_iterator it = bmarks.constEnd(); it != bmarks.constBegin(); --it )
