@@ -12,10 +12,11 @@
 
 #include <kbookmark.h>
 
-#include "okular_export.h"
+#include "okularcore_export.h"
+#include <QObject>
+#include <QUrl>
 
 class QAction;
-class KUrl;
 
 namespace Okular {
 
@@ -29,7 +30,7 @@ class DocumentViewport;
  * This class is responsible for loading and saving the bookmarks using the
  * proper format, and for working with them (eg querying, adding, removing).
  */
-class OKULAR_EXPORT BookmarkManager : public QObject
+class OKULARCORE_EXPORT BookmarkManager : public QObject
 {
     Q_OBJECT
 
@@ -39,12 +40,12 @@ class OKULAR_EXPORT BookmarkManager : public QObject
         /**
          * Returns the list of documents with bookmarks.
          */
-        KUrl::List files() const;
+        QList<QUrl> files() const;
 
         /**
          * Returns the list of bookmarks for the specified @p url.
          */
-        KBookmark::List bookmarks( const KUrl& url ) const;
+        KBookmark::List bookmarks( const QUrl& url ) const;
 
         /**
          * Returns the list of bookmarks for document
@@ -90,9 +91,9 @@ class OKULAR_EXPORT BookmarkManager : public QObject
          * Adds a new bookmark for the @p referurl at the specified viewport @p vp,
          * with an optional @p title.
          *
-         * If no @p title is specified, then \em #n will be used.
+         * If no @p title is specified, then \em \#n will be used.
          */
-        bool addBookmark( const KUrl& referurl, const Okular::DocumentViewport& vp, const QString& title = QString() );
+        bool addBookmark( const QUrl& referurl, const Okular::DocumentViewport& vp, const QString& title = QString() );
 
         /**
          * Remove a bookmark for the given @p page.
@@ -108,7 +109,7 @@ class OKULAR_EXPORT BookmarkManager : public QObject
         /**
          * Removes the bookmark @p bm for the @p referurl specified.
          */
-        int removeBookmark( const KUrl& referurl, const KBookmark& bm );
+        int removeBookmark( const QUrl& referurl, const KBookmark& bm );
 
         /**
          * Removes the bookmarks in @p list for the @p referurl specified.
@@ -117,7 +118,7 @@ class OKULAR_EXPORT BookmarkManager : public QObject
          *
          * @since 0.11 (KDE 4.5)
          */
-        void removeBookmarks( const KUrl& referurl, const KBookmark::List& list );
+        void removeBookmarks( const QUrl& referurl, const KBookmark::List& list );
 
         /**
          * Returns the bookmark given bookmark of the document
@@ -130,13 +131,13 @@ class OKULAR_EXPORT BookmarkManager : public QObject
          * the @p newName specified.
          * @since 0.15 (KDE 4.9)
          */
-        void renameBookmark( const KUrl& referurl, const QString& newName );
+        void renameBookmark( const QUrl& referurl, const QString& newName );
 
         /**
          * Returns title for the @p referurl
          * @since 0.15 (KDE 4.9)
          */
-        QString titleForUrl( const KUrl& referurl ) const;
+        QString titleForUrl( const QUrl& referurl ) const;
 
         /**
          * Returns whether the given @p page is bookmarked.
@@ -167,13 +168,13 @@ class OKULAR_EXPORT BookmarkManager : public QObject
          * @note the actions will have no parents, so you have to delete them
          * yourself
          */
-        QList< QAction* > actionsForUrl( const KUrl& url ) const;
+        QList< QAction* > actionsForUrl( const QUrl& url ) const;
 
     Q_SIGNALS:
         /**
          * The bookmark manager is requesting to open the specified @p url.
          */
-        void openUrl( const KUrl& url );
+        void openUrl( const QUrl& url );
 
         /**
          * This signal is emitted whenever bookmarks have been saved.
@@ -185,7 +186,7 @@ class OKULAR_EXPORT BookmarkManager : public QObject
          *
          * @since 0.7 (KDE 4.1)
          */
-        void bookmarksChanged( const KUrl& url );
+        void bookmarksChanged( const QUrl& url );
 
     private:
         class Private;
@@ -198,7 +199,7 @@ class OKULAR_EXPORT BookmarkManager : public QObject
 
         BookmarkManager( DocumentPrivate * document );
 
-        void setUrl( const KUrl& url );
+        void setUrl( const QUrl& url );
         bool setPageBookmark( int page );
         bool removePageBookmark( int page );
 
