@@ -167,7 +167,7 @@ MiniBar::MiniBar( QWidget * parent, MiniBarLogic * miniBarLogic )
     QSize buttonSize( KIconLoader::SizeSmallMedium, KIconLoader::SizeSmallMedium );
     // bottom: left prev_page button
     m_prevButton = new HoverButton( this );
-    m_prevButton->setIcon( QIcon::fromTheme( layoutDirection() == Qt::RightToLeft ? QStringLiteral("arrow-right") : QStringLiteral("arrow-left") ) );
+    m_prevButton->setIcon( QIcon::fromTheme( QStringLiteral("arrow-up") ) );
     m_prevButton->setIconSize( buttonSize );
     horLayout->addWidget( m_prevButton );
     // bottom: left lineEdit (current page box)
@@ -190,7 +190,7 @@ MiniBar::MiniBar( QWidget * parent, MiniBarLogic * miniBarLogic )
     horLayout->addWidget( m_pagesButton );
     // bottom: right next_page button
     m_nextButton = new HoverButton( this );
-    m_nextButton->setIcon( QIcon::fromTheme( layoutDirection() == Qt::RightToLeft ? QStringLiteral("arrow-left") : QStringLiteral("arrow-right") ) );
+    m_nextButton->setIcon( QIcon::fromTheme( QStringLiteral ("arrow-down") ) );
     m_nextButton->setIconSize( buttonSize );
     horLayout->addWidget( m_nextButton );
 
@@ -412,7 +412,7 @@ void ProgressWidget::paintEvent( QPaintEvent * e )
         p.fillRect( fRect, pal.color( QPalette::Active, QPalette::Highlight ) );
     if ( l && l != w  )
     {
-        p.setPen( pal.color( QPalette::Active, QPalette::Highlight ).dark( 120 ) );
+        p.setPen( pal.color( QPalette::Active, QPalette::Highlight ).darker( 120 ) );
         int delta = QApplication::isRightToLeft() ? w - l : l;
         p.drawLine( delta, 0, delta, h );
     }
@@ -540,7 +540,7 @@ void PagesEdit::updatePalette()
     if ( hasFocus() )
         pal.setColor( QPalette::Active, QPalette::Base, QApplication::palette().color( QPalette::Active, QPalette::Base ) );
     else
-        pal.setColor( QPalette::Base, QApplication::palette().color( QPalette::Base ).dark( 102 ) );
+        pal.setColor( QPalette::Base, QApplication::palette().color( QPalette::Base ).darker( 102 ) );
 
     setPalette( pal );
 }
